@@ -93,4 +93,10 @@ class CreateDBNodesRequest(RpcRequest):
 			if DBNodes[depth1].get('TargetClass') is not None:
 				self.add_query_param('DBNode.' + str(depth1 + 1) + '.TargetClass', DBNodes[depth1].get('TargetClass'))
 			if DBNodes[depth1].get('ZoneId') is not None:
-				self.add_query_param('DBNode.' + str(depth1 + 1) + '.ZoneId', DBNodes[depth1].get('ZoneId'))
\ No newline at end of file
+				self.add_query_param('DBNode.' + str(depth1 + 1) + '.ZoneId', DBNodes[depth1].get('ZoneId'))
+
+	def get_ImciSwitch(self):
+		return self.get_query_params().get('ImciSwitch')
+
+	def set_ImciSwitch(self,ImciSwitch):
+		self.add_query_param('ImciSwitch',ImciSwitch)
\ No newline at end of file
