@@ -37,6 +37,12 @@ class DescribeScheduleTasksRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
+	def get_DBClusterDescription(self):
+		return self.get_query_params().get('DBClusterDescription')
+
+	def set_DBClusterDescription(self,DBClusterDescription):
+		self.add_query_param('DBClusterDescription',DBClusterDescription)
+
 	def get_PageNumber(self):
 		return self.get_query_params().get('PageNumber')
 
@@ -55,6 +61,12 @@ class DescribeScheduleTasksRequest(RpcRequest):
 	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
 		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
 
+	def get_OrderId(self):
+		return self.get_query_params().get('OrderId')
+
+	def set_OrderId(self,OrderId):
+		self.add_query_param('OrderId',OrderId)
+
 	def get_DBClusterId(self):
 		return self.get_query_params().get('DBClusterId')
 
